Module data

Module data 

Data structures for statistical computing

This module provides columnar data structures optimized for statistical operations, with interoperability with numpy and pandas.

Structs

DataFrame
A DataFrame represents a collection of named Series (columns)
Series
A Series represents a single column of data with a name and dtype

Traits

FromData
Trait for converting external data formats to StatOxide structures
ToData
Trait for exporting StatOxide structures to external formats